@@ -38,23 +38,24 @@
 #include <camel/camel-file-utils.h>
 #include <camel/camel-folder-summary.h>
 #include <camel/camel-data-cache.h>
+#include <camel/camel-string-utils.h>
 
 #include "camel-exchange-journal.h"
 #include "camel-exchange-store.h"
 #include "camel-exchange-summary.h"
 
 
-#define d(x) x
+#define d(x)
 
 
 static void camel_exchange_journal_class_init (CamelExchangeJournalClass *klass);
 static void camel_exchange_journal_init (CamelExchangeJournal *journal, CamelExchangeJournalClass *klass);
 static void camel_exchange_journal_finalize (CamelObject *object);
 
-static void exchange_entry_free (CamelOfflineJournal *journal, EDListNode *entry);
-static EDListNode *exchange_entry_load (CamelOfflineJournal *journal, FILE *in);
-static int exchange_entry_write (CamelOfflineJournal *journal, EDListNode *entry, FILE *out);
-static int exchange_entry_play (CamelOfflineJournal *journal, EDListNode *entry, CamelException *ex);
+static void exchange_entry_free (CamelOfflineJournal *journal, CamelDListNode *entry);
+static CamelDListNode *exchange_entry_load (CamelOfflineJournal *journal, FILE *in);
+static int exchange_entry_write (CamelOfflineJournal *journal, CamelDListNode *entry, FILE *out);
+static int exchange_entry_play (CamelOfflineJournal *journal, CamelDListNode *entry, CamelException *ex);
 
 
 static CamelOfflineJournalClass *parent_class = NULL;
@@ -64,7 +65,7 @@ CamelType
 camel_exchange_journal_get_type (void)
 {
 	static CamelType type = 0;
-	
+
 	if (!type) {
 		type = camel_type_register (camel_offline_journal_get_type (),
 					    "CamelExchangeJournal",
@@ -75,7 +76,7 @@ camel_exchange_journal_get_type (void)
 					    (CamelObjectInitFunc) camel_exchange_journal_init,
 					    (CamelObjectFinalizeFunc) camel_exchange_journal_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -83,9 +84,9 @@ static void
 camel_exchange_journal_class_init (CamelExchangeJournalClass *klass)
 {
 	CamelOfflineJournalClass *journal_class = (CamelOfflineJournalClass *) klass;
-	
+
 	parent_class = (CamelOfflineJournalClass *) camel_type_get_global_classfuncs (CAMEL_TYPE_OFFLINE_JOURNAL);
-	
+
 	journal_class->entry_free = exchange_entry_free;
 	journal_class->entry_load = exchange_entry_load;
 	journal_class->entry_write = exchange_entry_write;
@@ -95,42 +96,42 @@ camel_exchange_journal_class_init (CamelExchangeJournalClass *klass)
 static void
 camel_exchange_journal_init (CamelExchangeJournal *journal, CamelExchangeJournalClass *klass)
 {
-	
+
 }
 
 static void
 camel_exchange_journal_finalize (CamelObject *object)
 {
-	
+
 }
 
 static void
-exchange_entry_free (CamelOfflineJournal *journal, EDListNode *entry)
+exchange_entry_free (CamelOfflineJournal *journal, CamelDListNode *entry)
 {
 	CamelExchangeJournalEntry *exchange_entry = (CamelExchangeJournalEntry *) entry;
-	
+
 	g_free (exchange_entry->uid);
 	g_free (exchange_entry->original_uid);
 	g_free (exchange_entry->folder_name);
 	g_free (exchange_entry);
 }
 
-static EDListNode *
+static CamelDListNode *
 exchange_entry_load (CamelOfflineJournal *journal, FILE *in)
 {
 	CamelExchangeJournalEntry *entry;
 	char *tmp;
-	
+
 	entry = g_malloc0 (sizeof (CamelExchangeJournalEntry));
-	
+
 	if (camel_file_util_decode_uint32 (in, (guint32 *) &entry->type) == -1)
 		goto exception;
-	
+
 	switch (entry->type) {
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND:
 		if (camel_file_util_decode_string (in, &entry->uid) == -1)
 			goto exception;
-		
+
 		break;
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_TRANSFER:
 		if (camel_file_util_decode_string (in, &entry->uid) == -1)
@@ -162,28 +163,28 @@ exchange_entry_load (CamelOfflineJournal *journal, FILE *in)
 	default:
 		goto exception;
 	}
-	
-	return (EDListNode *) entry;
-	
+
+	return (CamelDListNode *) entry;
+
  exception:
-	
+
 	g_free (entry->folder_name);
 	g_free (entry->original_uid);
 	g_free (entry->uid);
 	g_free (entry);
-	
+
 	return NULL;
 }
 
 static int
-exchange_entry_write (CamelOfflineJournal *journal, EDListNode *entry, FILE *out)
+exchange_entry_write (CamelOfflineJournal *journal, CamelDListNode *entry, FILE *out)
 {
 	CamelExchangeJournalEntry *exchange_entry = (CamelExchangeJournalEntry *) entry;
 	char *tmp;
-	
+
 	if (camel_file_util_encode_uint32 (out, exchange_entry->type) == -1)
 		return -1;
-	
+
 	switch (exchange_entry->type) {
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND:
 		if (camel_file_util_encode_string (out, exchange_entry->uid))
@@ -216,7 +217,7 @@ exchange_entry_write (CamelOfflineJournal *journal, EDListNode *entry, FILE *out
 		g_critical ("%s: Uncaught case (%d)", G_STRLOC, exchange_entry->type);
 		return -1;
 	}
-	
+
 	return 0;
 }
 
@@ -250,7 +251,7 @@ exchange_entry_play_delete (CamelOfflineJournal *journal, CamelExchangeJournalEn
 
 	return 0;
 }
-				
+
 static int
 exchange_entry_play_append (CamelOfflineJournal *journal, CamelExchangeJournalEntry *entry, CamelException *ex)
 {
@@ -261,28 +262,28 @@ exchange_entry_play_append (CamelOfflineJournal *journal, CamelExchangeJournalEn
 	CamelStream *stream;
 	CamelException lex;
 	char *uid = NULL;
-	
+
 	/* if the message isn't in the cache, the user went behind our backs so "not our problem" */
 	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, ex)))
 		goto done;
-	
+
 	message = camel_mime_message_new ();
 	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream) == -1) {
 		camel_object_unref (message);
 		camel_object_unref (stream);
 		goto done;
 	}
-	
+
 	camel_object_unref (stream);
-	
+
 	if (!(info = camel_folder_summary_uid (folder->summary, entry->uid))) {
 		/* Should have never happened, but create a new info to avoid further crashes */
 		info = camel_message_info_new (NULL);
 	}
-	
+
 	camel_exception_init (&lex);
 	camel_folder_append_message (folder, message, info, &uid, &lex);
-	
+
 	if (camel_exception_is_set (&lex)) {
 		camel_exception_xfer (ex, &lex);
 		return -1;
@@ -292,22 +293,22 @@ exchange_entry_play_append (CamelOfflineJournal *journal, CamelExchangeJournalEn
 	camel_object_unref (message);
 
 	if (uid != NULL && real) {
-		real->uid = g_strdup (uid);
+		real->uid = camel_pstring_strdup (uid);
 		exchange_message_info_dup_to ((CamelMessageInfoBase *) real, (CamelMessageInfoBase *) info);
 		camel_folder_summary_add (folder->summary, real);
 		/* FIXME: should a folder_changed event be triggered? */
 	}
 	camel_message_info_free (info);
 	g_free (uid);
-	
+
  done:
-	
+
 	camel_exchange_folder_remove_message (exchange_folder, entry->uid);
-	
+
 	return 0;
 }
 
-static int 
+static int
 exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournalEntry *entry, CamelException *ex)
 {
 	CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) journal->folder;
@@ -322,14 +323,14 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 
 	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, ex)))
 		goto done;
-	
+
 	message = camel_mime_message_new ();
 	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream) == -1) {
 		camel_object_unref (message);
 		camel_object_unref (stream);
 		goto done;
 	}
-	
+
 	camel_object_unref (stream);
 
 	if (!(info = camel_folder_summary_uid (folder->summary, entry->uid))) {
@@ -341,12 +342,12 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("No folder name found\n"));
 		goto exception;
 	}
-	
+
 	store = (CamelExchangeStore *) folder->parent_store;
 	g_mutex_lock (store->folders_lock);
 	src = (CamelFolder *) g_hash_table_lookup (store->folders, entry->folder_name);
 	g_mutex_unlock (store->folders_lock);
-	
+
 	if (src) {
 		uids = g_ptr_array_sized_new (1);
 		g_ptr_array_add (uids, entry->original_uid);
@@ -356,7 +357,7 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 		if (!camel_exception_is_set (&lex)) {
 			real = camel_folder_summary_info_new_from_message (folder->summary, message);
 			camel_object_unref (message);
-			real->uid = g_strdup ((char *)xuids->pdata[0]);
+			real->uid = camel_pstring_strdup ((char *)xuids->pdata[0]);
 			/* Transfer flags */
 			exchange_message_info_dup_to ((CamelMessageInfoBase *) real, (CamelMessageInfoBase *) info);
 			camel_folder_summary_add (folder->summary, real);
@@ -368,8 +369,8 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 
 		g_ptr_array_free (xuids, TRUE);
 		g_ptr_array_free (uids, TRUE);
-		/* camel_object_unref (src); FIXME: should we? */ 
-	} 
+		/* camel_object_unref (src); FIXME: should we? */
+	}
 	else {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Folder doesn't exist"));
 		goto exception;
@@ -382,17 +383,17 @@ done:
 	return 0;
 
 exception:
-	
+
 	camel_message_info_free (info);
 
 	return -1;
 }
 
 static int
-exchange_entry_play (CamelOfflineJournal *journal, EDListNode *entry, CamelException *ex)
+exchange_entry_play (CamelOfflineJournal *journal, CamelDListNode *entry, CamelException *ex)
 {
 	CamelExchangeJournalEntry *exchange_entry = (CamelExchangeJournalEntry *) entry;
-	
+
 	switch (exchange_entry->type) {
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND:
 		return exchange_entry_play_append (journal, exchange_entry, ex);
@@ -412,12 +413,12 @@ CamelOfflineJournal *
 camel_exchange_journal_new (CamelExchangeFolder *folder, const char *filename)
 {
 	CamelOfflineJournal *journal;
-	
+
 	g_return_val_if_fail (CAMEL_IS_EXCHANGE_FOLDER (folder), NULL);
-	
+
 	journal = (CamelOfflineJournal *) camel_object_new (camel_exchange_journal_get_type ());
 	camel_offline_journal_construct (journal, (CamelFolder *) folder, filename);
-	
+
 	return journal;
 }
 
@@ -438,16 +439,16 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 				     _("Cannot append message in offline mode: cache unavailable"));
 		return FALSE;
 	}
-	
+
 	nextuid = camel_folder_summary_next_uid (folder->summary);
 	uid = g_strdup_printf ("-%u", nextuid);
-	
+
 	if (!(cache = camel_data_cache_add (exchange_folder->cache, "cache", uid, ex))) {
 		folder->summary->nextuid--;
 		g_free (uid);
 		return FALSE;
 	}
-	
+
 	if (camel_data_wrapper_write_to_stream ((CamelDataWrapper *) message, cache) == -1
 	    || camel_stream_flush (cache) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
@@ -459,16 +460,16 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 		g_free (uid);
 		return FALSE;
 	}
-	
+
 	camel_object_unref (cache);
-	
+
 	info = camel_folder_summary_info_new_from_message (folder->summary, message);
-	info->uid = g_strdup (uid);
-	
+	info->uid = camel_pstring_strdup (uid);
+
 	exchange_message_info_dup_to ((CamelMessageInfoBase *) info, (CamelMessageInfoBase *) mi);
 
 	camel_folder_summary_add (folder->summary, info);
-	
+
 	if (updated_uid)
 		*updated_uid = g_strdup (uid);
 
@@ -484,16 +485,16 @@ camel_exchange_journal_append (CamelExchangeJournal *exchange_journal, CamelMime
 	CamelOfflineJournal *journal = (CamelOfflineJournal *) exchange_journal;
 	CamelExchangeJournalEntry *entry;
 	char *uid;
-	
+
 	if (!update_cache (exchange_journal, message, mi, &uid, ex))
 		return;
-	
+
 	entry = g_new (CamelExchangeJournalEntry, 1);
 	entry->type = CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND;
 	entry->uid = uid;
-	
-	e_dlist_addtail (&journal->queue, (EDListNode *) entry);
-	
+
+	camel_dlist_addtail (&journal->queue, (CamelDListNode *) entry);
+
 	if (appended_uid)
 		*appended_uid = g_strdup (uid);
 
@@ -506,11 +507,11 @@ find_real_source_for_message (CamelExchangeFolder *folder,
 			      gboolean delete_original)
 {
 	CamelOfflineJournal *journal = folder->journal;
-	EDListNode *entry, *next;
+	CamelDListNode *entry, *next;
 	CamelExchangeJournalEntry *ex_entry;
 	const char *offline_uid = *uid;
 	int type = -1;
-	
+
 	if (*offline_uid != '-') {
 		return CAMEL_EXCHANGE_JOURNAL_ENTRY_TRANSFER;
 	}
@@ -518,7 +519,7 @@ find_real_source_for_message (CamelExchangeFolder *folder,
 	entry = journal->queue.head;
 	while (entry->next) {
 		next = entry->next;
-		
+
 		ex_entry = (CamelExchangeJournalEntry *) entry;
 		if (!g_ascii_strcasecmp (ex_entry->uid, offline_uid)) {
 			if (ex_entry->type == CAMEL_EXCHANGE_JOURNAL_ENTRY_TRANSFER) {
@@ -530,17 +531,17 @@ find_real_source_for_message (CamelExchangeFolder *folder,
 			}
 
 			if (delete_original) {
-				e_dlist_remove (entry);
+				camel_dlist_remove (entry);
 			}
 		}
-		
+
 		entry = next;
 	}
 
 	return type;
 }
 
-void 
+void
 camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelExchangeFolder *source_folder,
 				CamelMimeMessage *message, const CamelMessageInfo *mi,
 				const char *original_uid, char **transferred_uid, gboolean delete_original,
@@ -551,16 +552,16 @@ camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelEx
 	char *uid;
 	const char *real_source_folder = NULL, *real_uid = NULL;
 	int type;
-	
+
 	if (!update_cache (exchange_journal, message, mi, &uid, ex))
 		return;
 
 	real_uid = original_uid;
 	real_source_folder = ((CamelFolder *)source_folder)->full_name;
-	
+
 	type = find_real_source_for_message (source_folder, &real_source_folder,
 					     &real_uid, delete_original);
-	
+
 	if(delete_original) {
 		camel_exchange_folder_remove_message (source_folder, original_uid);
 	}
@@ -575,8 +576,8 @@ camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelEx
 		entry->delete_original = delete_original;
 	}
 
-	e_dlist_addtail (&journal->queue, (EDListNode *) entry);
-	
+	camel_dlist_addtail (&journal->queue, (CamelDListNode *) entry);
+
 	if (transferred_uid)
 		*transferred_uid = g_strdup (uid);
 }
@@ -599,6 +600,6 @@ camel_exchange_journal_delete (CamelExchangeJournal *exchange_journal,
 	entry->flags = flags;
 	entry->set = set;
 
-	e_dlist_addtail (&journal->queue, (EDListNode *) entry);
+	camel_dlist_addtail (&journal->queue, (CamelDListNode *) entry);
 }
 
