@@ -26,6 +26,7 @@
 
 #include <glib.h>
 
+#include <camel/camel-list-utils.h>
 #include <camel/camel-offline-journal.h>
 #include <camel/camel-mime-message.h>
 #include "camel-exchange-folder.h"
@@ -55,7 +56,7 @@ enum {
 };
 
 struct _CamelExchangeJournalEntry {
-	EDListNode node;
+	CamelDListNode node;
 
 	int type;
 
